==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/lv-LV/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Apstiprināt lielapjoma aktīvu dzēšanu',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Pārskatīt aktīvu lielapjoma dzēšanu zemāk. Dzēstos aktīvus var atjaunot, bet tie vairs nebūs saistīti ar šībrīža lietotāju.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Jūs gatavojaties dzēst: asset_count aktīvi.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Lielapjoma atjaunināšanas līdzekļi',
    'bulk_update_help'	=> 'Šī veidlapa ļauj vienlaikus atjaunināt vairākus aktīvus. Aizpildiet tikai nepieciešamos laukus. Jebkurš tukšs laukums paliek nemainīgs.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Izrakstīts uz',
    'checkout_date'		=> 'Izrakstīšanās datums',
    'checkin_date'		=> 'Reģistrēšanās datums',
    'checkout_to'		=> 'Izrakstīšanās līdz',
    'cost'				=> 'Iegādes izmaksas',
    'create'			=> 'Izveidot īpašumu',
    'date'				=> 'Pirkuma datums',
    'depreciation'	    => 'Nolietojums',
    'depreciates_on'	=> 'Atbalstīts ieslēgts',
    'default_location'	=> 'Noklusējuma atrašanās vieta',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL datums',
    'eol_rate'			=> 'EOL likme',
    'expected_checkin'  => 'Paredzamais reģistrēšanās datums',
    'expires'			=> 'Beidzas',
    'fully_depreciated'	=> 'Pilnībā nolietota',
    'help_checkout'		=> 'Ja vēlaties piešķirt šo priekšmetu uzreiz, atlasiet "Gatavs izvietošanai" no iepriekšējā statusa saraksta.',
    'mac_address'		=> 'MAC adrese',
    'manufacturer'		=> 'Ražotājs',
    'model'				=> 'Modelis',
    'months'			=> 'mēneši',
    'name'				=> 'Aktīva nosaukums',
    'notes'				=> 'Piezīmes',
    'order'				=> 'Pasūtījuma numurs',
    'qr'				=> 'QR kods',
    'requestable'		=> 'Lietotāji var pieprasīt šo aktīvu',
    'select_statustype'	=> 'Atlasiet statusa veidu',
    'serial'			=> 'Sērijas numurs',
    'status'			=> 'Statuss',
    'tag'				=> 'Asset Tag',
    'update'			=> 'Aktīvu atjaunošana',
    'warranty'			=> 'Garantija',
        'warranty_expires'		=> 'Garantija beidzās',
    'years'				=> 'gadiem',
    'asset_location' => 'Atjaunināt pamatlīdzekļa atrašanās vietu',
    'asset_location_update_default_current' => 'Atjaunināt noklusējuma KĀ ARĪ tekošo atrašanās vietu',
    'asset_location_update_default' => 'Atjaunināt tikai noklusēja atrašanās vietu',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'Šis statuss nav izmantojams. Pamatlīdzeklis nevar tikt izrakstīts.',
    'asset_deployable' => 'Šis statuss ir izmantojams. Pamatlīdzeklis ir pieejams izrakstīšanai.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Neobligātā informācija',
    'order_details'   => 'Pasūtījuma informācija'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/lv-LV/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Apstiprināt lielapjoma aktīvu dzēšanu',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Pārskatīt aktīvu lielapjoma dzēšanu zemāk. Dzēstos aktīvus var atjaunot, bet tie vairs nebūs saistīti ar šībrīža lietotāju.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Jūs gatavojaties dzēst: asset_count aktīvi.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Lielapjoma atjaunināšanas līdzekļi',
    'bulk_update_help'	=> 'Šī veidlapa ļauj vienlaikus atjaunināt vairākus aktīvus. Aizpildiet tikai nepieciešamos laukus. Jebkurš tukšs laukums paliek nemainīgs.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Izrakstīts uz',
    'checkout_date'		=> 'Izrakstīšanās datums',
    'checkin_date'		=> 'Reģistrēšanās datums',
    'checkout_to'		=> 'Izrakstīšanās līdz',
    'cost'				=> 'Iegādes izmaksas',
    'create'			=> 'Izveidot īpašumu',
    'date'				=> 'Pirkuma datums',
    'depreciation'	    => 'Nolietojums',
    'depreciates_on'	=> 'Atbalstīts ieslēgts',
    'default_location'	=> 'Noklusējuma atrašanās vieta',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL datums',
    'eol_rate'			=> 'EOL likme',
    'expected_checkin'  => 'Paredzamais reģistrēšanās datums',
    'expires'			=> 'Beidzas',
    'fully_depreciated'	=> 'Pilnībā nolietota',
    'help_checkout'		=> 'Ja vēlaties piešķirt šo priekšmetu uzreiz, atlasiet "Gatavs izvietošanai" no iepriekšējā statusa saraksta.',
    'mac_address'		=> 'MAC adrese',
    'manufacturer'		=> 'Ražotājs',
    'model'				=> 'Modelis',
    'months'			=> 'mēneši',
    'name'				=> 'Aktīva nosaukums',
    'notes'				=> 'Piezīmes',
    'order'				=> 'Pasūtījuma numurs',
    'qr'				=> 'QR kods',
    'requestable'		=> 'Lietotāji var pieprasīt šo aktīvu',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Atlasiet statusa veidu',
    'serial'			=> 'Sērijas numurs',
    'status'			=> 'Statuss',
    'tag'				=> 'Asset Tag',
    'update'			=> 'Aktīvu atjaunošana',
    'warranty'			=> 'Garantija',
        'warranty_expires'		=> 'Garantija beidzās',
    'years'				=> 'gadiem',
    'asset_location' => 'Atjaunināt pamatlīdzekļa atrašanās vietu',
    'asset_location_update_default_current' => 'Atjaunināt noklusējuma KĀ ARĪ tekošo atrašanās vietu',
    'asset_location_update_default' => 'Atjaunināt tikai noklusēja atrašanās vietu',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'Šis statuss nav izmantojams. Pamatlīdzeklis nevar tikt izrakstīts.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Šis statuss ir izmantojams. Pamatlīdzeklis ir pieejams izrakstīšanai.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Neobligātā informācija',
    'order_details'   => 'Pasūtījuma informācija'
];
